@@ -13,11 +13,13 @@ import glob
 import shutil
 import pyasn
 import pypdns
+import pytz
 from IPy import IP
 from dateutil.parser import parse
 from harpoon.commands.base import Command
 from harpoon.lib.utils import bracket, unbracket
 from harpoon.lib.robtex import Robtex, RobtexError
+from harpoon.lib.urlscan import UrlScan
 from OTXv2 import OTXv2, IndicatorTypes
 from virus_total_apis import PublicApi, PrivateApi
 from pygreynoisev1 import GreyNoise, GreyNoiseError
@@ -91,34 +93,49 @@ class CommandDomain(Command):
                 otx_e = plugins['otx'].test_config(conf)
                 if otx_e:
                     print('[+] Downloading OTX information....')
-                    otx = OTXv2(conf["AlienVaultOtx"]["key"])
-                    res = otx.get_indicator_details_full(IndicatorTypes.DOMAIN, unbracket(args.DOMAIN))
-                    otx_pulses =  res["general"]["pulse_info"]["pulses"]
-                    # Get Passive DNS
-                    if "passive_dns" in res:
-                        for r in res["passive_dns"]["passive_dns"]:
-                            passive_dns.append({
-                                "ip": r['hostname'],
-                                "first": parse(r["first"]),
-                                "last": parse(r["last"]),
-                                "source" : "OTX"
-                            })
-                    if "url_list" in res:
-                        for r in res["url_list"]["url_list"]:
-                            if "result" in r:
-                                urls.append({
-                                    "date": parse(r["date"]),
-                                    "url": r["url"],
-                                    "ip": r["result"]["urlworker"]["ip"] if "ip" in r["result"]["urlworker"] else "" ,
-                                    "source": "OTX"
-                                })
-                            else:
-                                urls.append({
-                                    "date": parse(r["date"]),
-                                    "url": r["url"],
-                                    "ip": "",
-                                    "source": "OTX"
+                    try:
+                        otx = OTXv2(conf["AlienVaultOtx"]["key"])
+                        res = otx.get_indicator_details_full(IndicatorTypes.DOMAIN, unbracket(args.DOMAIN))
+                        otx_pulses =  res["general"]["pulse_info"]["pulses"]
+                        # Get Passive DNS
+                        if "passive_dns" in res:
+                            for r in res["passive_dns"]["passive_dns"]:
+                                passive_dns.append({
+                                    "ip": r['hostname'],
+                                    "first": parse(r["first"]).astimezone(pytz.utc),
+                                    "last": parse(r["last"]).astimezone(pytz.utc),
+                                    "source" : "OTX"
                                 })
+                        if "url_list" in res:
+                            for r in res["url_list"]["url_list"]:
+                                if "result" in r:
+                                    urls.append({
+                                        "date": parse(r["date"]).astimezone(pytz.utc),
+                                        "url": r["url"],
+                                        "ip": r["result"]["urlworker"]["ip"] if "ip" in r["result"]["urlworker"] else "" ,
+                                        "source": "OTX"
+                                    })
+                                else:
+                                    urls.append({
+                                        "date": parse(r["date"]).astimezone(pytz.utc),
+                                        "url": r["url"],
+                                        "ip": "",
+                                        "source": "OTX"
+                                    })
+                    except AttributeError:
+                        print('OTX crashed  ¯\_(ツ)_/¯')
+                # UrlScan
+                us = UrlScan()
+                print('[+] Downloading UrlScan information....')
+                res = us.search(args.DOMAIN)
+                for r in res['results']:
+                    urls.append({
+                        "date": parse(r["task"]["time"]).astimezone(pytz.utc),
+                        "url": r["page"]["url"],
+                        "ip": r["page"]["ip"] if "ip" in r["page"] else "",
+                        "source": "UrlScan"
+                    })
+
                 # CIRCL
                 circl_e = plugins['circl'].test_config(conf)
                 if circl_e:
@@ -133,25 +150,28 @@ class CommandDomain(Command):
                     for answer in res:
                         passive_dns.append({
                             "ip": answer['rdata'],
-                            "first": answer['time_first'],
-                            "last": answer['time_last'],
+                            "first": answer['time_first'].astimezone(pytz.utc),
+                            "last": answer['time_last'].astimezone(pytz.utc),
                             "source" : "CIRCL"
                         })
                 # BinaryEdge
                 be_e = plugins['binaryedge'].test_config(conf)
                 if be_e:
                     print('[+] Downloading BinaryEdge information....')
-                    be = BinaryEdge(conf['BinaryEdge']['key'])
-                    res = be.domain_dns(unbracket(args.DOMAIN))
-                    for d in res['events']:
-                        if "A" in d:
-                            for a in d['A']:
-                                passive_dns.append({
-                                    "ip": a,
-                                    "first": parse(d['updated_at']),
-                                    "last": parse(d['updated_at']),
-                                    "source" : "BinaryEdge"
-                                })
+                    try:
+                        be = BinaryEdge(conf['BinaryEdge']['key'])
+                        res = be.domain_dns(unbracket(args.DOMAIN))
+                        for d in res['events']:
+                            if "A" in d:
+                                for a in d['A']:
+                                    passive_dns.append({
+                                        "ip": a,
+                                        "first": parse(d['updated_at']).astimezone(pytz.utc),
+                                        "last": parse(d['updated_at']).astimezone(pytz.utc),
+                                        "source" : "BinaryEdge"
+                                    })
+                    except BinaryEdgeException:
+                        print('You need a paid BinaryEdge subscription for this request')
                 # RobTex
                 print('[+] Downloading Robtex information....')
                 rob = Robtex()
@@ -159,8 +179,8 @@ class CommandDomain(Command):
                 for d in res:
                     if d['rrtype'] in ['A', 'AAAA']:
                         passive_dns.append({
-                            'first': d['time_first_o'],
-                            'last': d['time_last_o'],
+                            'first': d['time_first_o'].astimezone(pytz.utc),
+                            'last': d['time_last_o'].astimezone(pytz.utc),
                             'ip': d['rrdata'],
                             'source': 'Robtex'
                         })
@@ -177,8 +197,8 @@ class CommandDomain(Command):
                         if "results" in raw_results:
                             for res in raw_results["results"]:
                                 passive_dns.append({
-                                    "first": parse(res["firstSeen"]),
-                                    "last": parse(res["lastSeen"]),
+                                    "first": parse(res["firstSeen"]).astimezone(pytz.utc),
+                                    "last": parse(res["lastSeen"]).astimezone(pytz.utc),
                                     "ip": res["resolve"],
                                     "source": "PT"
                                 })
@@ -197,7 +217,7 @@ class CommandDomain(Command):
                                 for r in raw_results["results"]:
                                     malware.append({
                                         'hash': r["sample"],
-                                        'date': parse(r['collectionDate']),
+                                        'date': parse(r['collectionDate']).astimezone(pytz.utc),
                                         'source' : 'PT (%s)' % r["source"]
                                     })
                     except requests.exceptions.ReadTimeout:
@@ -213,8 +233,8 @@ class CommandDomain(Command):
                             if "resolutions" in res['results']:
                                 for r in res["results"]["resolutions"]:
                                     passive_dns.append({
-                                        "first": parse(r["last_resolved"]),
-                                        "last": parse(r["last_resolved"]),
+                                        "first": parse(r["last_resolved"]).astimezone(pytz.utc),
+                                        "last": parse(r["last_resolved"]).astimezone(pytz.utc),
                                         "ip": r["ip_address"],
                                         "source": "VT"
                                     })
@@ -222,21 +242,21 @@ class CommandDomain(Command):
                                 for r in res['results']['undetected_downloaded_samples']:
                                     files.append({
                                         'hash': r['sha256'],
-                                        'date': parse(r['date']) if 'date' in r else '',
+                                        'date': parse(r['date']).astimezone(pytz.utc) if 'date' in r else '',
                                         'source' : 'VT'
                                     })
                             if "undetected_referrer_samples" in res['results']:
                                 for r in res['results']['undetected_referrer_samples']:
                                     files.append({
                                         'hash': r['sha256'],
-                                        'date': parse(r['date']) if 'date' in r else '',
+                                        'date': parse(r['date']).astimezone(pytz.utc) if 'date' in r else '',
                                         'source' : 'VT'
                                     })
                             if "detected_downloaded_samples" in res['results']:
                                 for r in res['results']['detected_downloaded_samples']:
                                     malware.append({
                                         'hash': r['sha256'],
-                                        'date': parse(r['date']),
+                                        'date': parse(r['date']).astimezone(pytz.utc),
                                         'source' : 'VT'
                                     })
                             if "detected_referrer_samples" in res['results']:
@@ -244,13 +264,13 @@ class CommandDomain(Command):
                                     if "date" in r:
                                         malware.append({
                                             'hash': r['sha256'],
-                                            'date': parse(r['date']),
+                                            'date': parse(r['date']).astimezone(pytz.utc),
                                             'source' : 'VT'
                                         })
                             if "detected_urls" in res['results']:
                                 for r in res['results']['detected_urls']:
                                     urls.append({
-                                        'date': parse(r['scan_date']),
+                                        'date': parse(r['scan_date']).astimezone(pytz.utc),
                                         'url': r['url'],
                                         'ip': '',
                                         'source': 'VT'
@@ -267,8 +287,7 @@ class CommandDomain(Command):
                         if 'items' in res:
                             for r in res['items']:
                                 if r['sample_sha256'] not in already:
-                                    d = parse(r['ts'])
-                                    d = d.replace(tzinfo=None)
+                                    d = parse(r['ts']).astimezone(pytz.utc)
                                     malware.append({
                                         'hash': r["sample_sha256"],
                                         'date': d,
@@ -360,7 +379,6 @@ class CommandDomain(Command):
                             )
                         )
 
-
             else:
                 self.parser.print_help()
         else:
