@@ -14,6 +14,7 @@ import pyasn
 import urllib
 import socket
 import requests
+import pytz
 from IPy import IP
 from dateutil.parser import parse
 from harpoon.commands.base import Command
@@ -57,8 +58,8 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
     description = "Gather information on an IP address"
     config = None
     update_needed = True
-    geocity = os.path.join(os.path.expanduser('~'), '.config/harpoon/GeoLite2-City.mmdb')
-    geoasn = os.path.join(os.path.expanduser('~'), '.config/harpoon/GeoLite2-ASN.mmdb')
+    geocity = "/usr/share/GeoIP/GeoLite2-City.mmdb"
+    geoasn = "/usr/share/GeoIP/GeoLite2-ASN.mmdb"
     asnname = os.path.join(os.path.expanduser('~'), '.config/harpoon/asnnames.csv')
     asncidr = os.path.join(os.path.expanduser('~'), '.config/harpoon/asncidr.dat')
     specific_ips = os.path.join(os.path.expanduser('~'), '.config/harpoon/iplist.csv')
@@ -74,42 +75,6 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
         self.parser = parser
 
     def update(self):
-        # Download Maxmind
-        print("Downloading MaxMind GeoIP Database")
-        try:
-            os.remove(self.geocity)
-        except OSError:
-            pass
-        try:
-            os.remove(self.geoasn)
-        except OSError:
-            pass
-        try:
-            file_name, headers = urllib.request.urlretrieve('http://geolite.maxmind.com/download/geoip/database/GeoLite2-City.tar.gz')
-            tar = tarfile.open(file_name, 'r')
-            for this_fn in tar.getmembers():
-                if this_fn.name.endswith("GeoLite2-City.mmdb"):
-                    mmdb = tar.extractfile(this_fn)
-                    with open(self.geocity, 'wb') as f:
-                        f.write(mmdb.read())
-                    mmdb.close()
-            print("-GeoLite2-City.mmdb")
-            file_name, headers = urllib.request.urlretrieve('http://geolite.maxmind.com/download/geoip/database/GeoLite2-ASN.tar.gz')
-            tar = tarfile.open(file_name, 'r')
-            for this_fn in tar.getmembers():
-                if this_fn.name.endswith("GeoLite2-ASN.mmdb"):
-                    mmdb = tar.extractfile(this_fn)
-                    with open(self.geoasn, 'wb') as f:
-                        f.write(mmdb.read())
-                    mmdb.close()
-            print("-GeoLite2-ASN.mmdb")
-        except urllib.error.HTTPError:
-            print("Impossible to download GeoIP databases, please check https://github.com/Te-k/harpoon/wiki/Known-bugs#cloudfare-blocking-download-of-maxmind-geoip-databases")
-        print("Downloading ASN Name database")
-        try:
-            os.remove(self.asnname)
-        except OSError:
-            pass
         file_name, headers = urllib.request.urlretrieve('http://www.cidr-report.org/as2.0/autnums.html')
         fin = open(file_name, 'r', encoding="latin-1", errors='ignore')
         fout = open(self.asnname, 'w+')
@@ -270,17 +235,20 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
                 # Binary Edge
                 be_e = plugins['binaryedge'].test_config(conf)
                 if be_e:
-                    print('[+] Downloading BinaryEdge information...')
-                    be = BinaryEdge(conf['BinaryEdge']['key'])
-                    # FIXME: this only get the first page
-                    res = be.domain_ip(unbracket(args.IP))
-                    for d in res["events"]:
-                        passive_dns.append({
-                            "domain": d['domain'],
-                            "first": parse(d['updated_at']),
-                            "last": parse(d['updated_at']),
-                            "source" : "BinaryEdge"
-                        })
+                    try:
+                        print('[+] Downloading BinaryEdge information...')
+                        be = BinaryEdge(conf['BinaryEdge']['key'])
+                        # FIXME: this only get the first page
+                        res = be.domain_ip(unbracket(args.IP))
+                        for d in res["events"]:
+                            passive_dns.append({
+                                "domain": d['domain'],
+                                "first": parse(d['updated_at']).astimezone(pytz.utc),
+                                "last": parse(d['updated_at']).astimezone(pytz.utc),
+                                "source" : "BinaryEdge"
+                            })
+                    except BinaryEdgeException:
+                        print('BinaryEdge request failed, you need a paid subscription')
                 # OTX
                 otx_e = plugins['otx'].test_config(conf)
                 if otx_e:
@@ -293,8 +261,8 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
                         for r in res["passive_dns"]["passive_dns"]:
                             passive_dns.append({
                                 "domain": r['hostname'],
-                                "first": parse(r["first"]),
-                                "last": parse(r["last"]),
+                                "first": parse(r["first"]).astimezone(pytz.utc),
+                                "last": parse(r["last"]).astimezone(pytz.utc),
                                 "source" : "OTX"
                             })
                     if "url_list" in res:
@@ -312,8 +280,8 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
                         if d in res:
                             for a in res[d]:
                                 passive_dns.append({
-                                    'first': a['date'],
-                                    'last': a['date'],
+                                    'first': a['date'].astimezone(pytz.utc),
+                                    'last': a['date'].astimezone(pytz.utc),
                                     'domain': a['o'],
                                     'source': 'Robtex'
                                 })
@@ -329,8 +297,8 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
                         if "results" in raw_results:
                             for res in raw_results["results"]:
                                 passive_dns.append({
-                                    "first": parse(res["firstSeen"]),
-                                    "last": parse(res["lastSeen"]),
+                                    "first": parse(res["firstSeen"]).astimezone(pytz.utc),
+                                    "last": parse(res["lastSeen"]).astimezone(pytz.utc),
                                     "domain": res["resolve"],
                                     "source": "PT"
                                 })
@@ -369,8 +337,8 @@ IP Location:    https://www.iplocation.net/?query=172.34.127.2
                             if "resolutions" in res['results']:
                                 for r in res["results"]["resolutions"]:
                                     passive_dns.append({
-                                        "first": parse(r["last_resolved"]),
-                                        "last": parse(r["last_resolved"]),
+                                        "first": parse(r["last_resolved"]).astimezone(pytz.utc),
+                                        "last": parse(r["last_resolved"]).astimezone(pytz.utc),
                                         "domain": r["hostname"],
                                         "source": "VT"
                                     })
